@@ -6,7 +6,7 @@ pub struct ContractAbi {
     pub build_info: BuildInfoAbi,
     pub docs: &'static [&'static str],
     pub name: &'static str,
-    pub constructor: Option<EndpointAbi>,
+    pub constructors: Vec<EndpointAbi>,
     pub endpoints: Vec<EndpointAbi>,
     pub has_callback: bool,
     pub type_descriptions: TypeDescriptionContainerImpl,
@@ -14,6 +14,8 @@ pub struct ContractAbi {
 
 impl ContractAbi {
     pub fn coalesce(&mut self, other: Self) {
+        self.constructors
+            .extend_from_slice(other.constructors.as_slice());
         self.endpoints.extend_from_slice(other.endpoints.as_slice());
         self.has_callback |= other.has_callback;
         self.type_descriptions.insert_all(&other.type_descriptions);
