@@ -37,6 +37,13 @@ pub trait ManagedBufferApi {
 
     fn mb_overwrite(&self, handle: Handle, value: &[u8]);
 
+    fn mb_set_slice(
+        &self,
+        dest_handle: Handle,
+        starting_position: usize,
+        source_slice: &[u8],
+    ) -> Result<(), InvalidSliceError>;
+
     fn mb_append(&self, accumulator_handle: Handle, data_handle: Handle);
 
     fn mb_append_bytes(&self, accumulator_handle: Handle, bytes: &[u8]);
