@@ -1,6 +1,6 @@
 use super::{
     BlockchainWrapper, CallValueWrapper, CryptoWrapper, ErrorHelper, ManagedSerializer,
-    ManagedTypeHelper, PrintHelper, SendWrapper,
+    PrintHelper, SendWrapper,
 };
 use crate::api::VMApi;
 
@@ -36,12 +36,6 @@ pub trait ContractBase: Sized {
         self.raw_vm_api()
     }
 
-    /// Helps create new instances of managed types
-    #[inline]
-    fn types(&self) -> ManagedTypeHelper<Self::Api> {
-        ManagedTypeHelper::new(self.raw_vm_api())
-    }
-
     /// Gateway blockchain info related to the current transaction and to accounts.
     #[inline]
     fn blockchain(&self) -> BlockchainWrapper<Self::Api> {
