@@ -36,17 +36,6 @@ impl<M: ManagedTypeApi> TokenIdentifier<M> {
     #[allow(clippy::needless_borrow)] // clippy is wrog here, there is no other way
     pub const EGLD_REPRESENTATION: &'static [u8; 4] = &b"EGLD";
 
-    pub const TICKER_MIN_LENGTH: usize = 3;
-    pub const TICKER_MAX_LENGTH: usize = 10;
-    pub const ADDITIONAL_RANDOM_CHARS_LENGTH: usize = 6;
-    // +1 because of the '-' (dash) between ticker and the random chars
-    pub const IDENTIFIER_MIN_LENGTH: usize =
-        Self::TICKER_MIN_LENGTH + Self::ADDITIONAL_RANDOM_CHARS_LENGTH + 1;
-    pub const IDENTIFIER_MAX_LENGTH: usize =
-        Self::TICKER_MAX_LENGTH + Self::ADDITIONAL_RANDOM_CHARS_LENGTH + 1;
-
-    pub const DASH_CHARACTER: u8 = b'-';
-
     #[inline]
     pub fn from_esdt_bytes<B: Into<ManagedBuffer<M>>>(bytes: B) -> Self {
         TokenIdentifier {
@@ -107,54 +96,8 @@ impl<M: ManagedTypeApi> TokenIdentifier<M> {
     }
 
     pub fn is_valid_esdt_identifier(&self) -> bool {
-        if self.is_egld() {
-            return false;
-        }
-
-        let id_len = self.buffer.len();
-        #[allow(clippy::manual_range_contains)]
-        if id_len < Self::IDENTIFIER_MIN_LENGTH || id_len > Self::IDENTIFIER_MAX_LENGTH {
-            return false;
-        }
-
-        let token_id_bytes = self.buffer.to_boxed_bytes();
-        let token_id_slice = token_id_bytes.as_slice();
-
-        let lowercase_letter_range = &b'a'..=&b'z';
-        let uppercase_letter_range = &b'A'..=&b'Z';
-        let number_range = &b'0'..=&b'9';
-
-        // ticker must be all uppercase alphanumeric
-        let ticker_len = id_len - Self::ADDITIONAL_RANDOM_CHARS_LENGTH - 1;
-        let ticker = &token_id_slice[..ticker_len];
-        for ticker_char in ticker {
-            let is_uppercase_letter = uppercase_letter_range.contains(&ticker_char);
-            let is_number = number_range.contains(&ticker_char);
-
-            if !is_uppercase_letter && !is_number {
-                return false;
-            }
-        }
-
-        let dash_position = ticker_len;
-        if token_id_slice[dash_position] != Self::DASH_CHARACTER {
-            return false;
-        }
-
-        // random chars are alphanumeric lowercase
-        let random_chars = &token_id_slice[(id_len - Self::ADDITIONAL_RANDOM_CHARS_LENGTH)..];
-        for rand_char in random_chars {
-            let is_lowercase_letter = lowercase_letter_range.contains(&rand_char);
-            let is_number = number_range.contains(&rand_char);
-
-            if !is_lowercase_letter && !is_number {
-                return false;
-            }
-        }
-
-        true
+        M::instance().validate_token_identifier(self.buffer.handle)
     }
-
     /// Converts `"EGLD"` to `""`.
     /// Does nothing for the other values.
     fn normalize(&mut self) {
