@@ -9,10 +9,11 @@ use alloc::string::String;
 /// Argument or result that is made up of the argument count, followed by the arguments themselves.
 /// Think of it as a `VarArgs` preceded by the count.
 /// Unlike `ManagedMultiResultVec` it deserializes eagerly.
+#[derive(Clone, Default)]
 pub struct ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem,
 {
     pub(super) contents: ManagedVec<M, T>,
 }
@@ -22,18 +23,18 @@ pub type ManagedCountedVarArgs<M, T> = ManagedCountedMultiResultVec<M, T>;
 impl<M, T> ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem,
 {
     #[inline]
-    pub fn new(api: M) -> Self {
-        ManagedCountedMultiResultVec::from(ManagedVec::new(api))
+    pub fn new() -> Self {
+        ManagedCountedMultiResultVec::from(ManagedVec::new())
     }
 }
 
 impl<M, T> ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem,
 {
     #[inline]
     pub fn len(&self) -> usize {
@@ -49,7 +50,7 @@ where
 impl<M, T> ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem,
 {
     #[inline]
     pub fn push(&mut self, item: T) {
@@ -65,7 +66,7 @@ where
 impl<M, T> From<ManagedVec<M, T>> for ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M>,
+    T: ManagedVecItem,
 {
     #[inline]
     #[rustfmt::skip]
@@ -79,10 +80,10 @@ where
 impl<M, T> DynArg for ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M> + DynArg,
+    T: ManagedVecItem + DynArg,
 {
     fn dyn_load<I: DynArgInput>(loader: &mut I, arg_id: ArgId) -> Self {
-        let mut result = ManagedCountedMultiResultVec::new(loader.vm_api_cast::<M>());
+        let mut result = ManagedCountedMultiResultVec::new();
         let count = usize::dyn_load(loader, arg_id);
         for _ in 0..count {
             result.contents.push(T::dyn_load(loader, arg_id));
@@ -94,7 +95,7 @@ where
 impl<M, T> EndpointResult for ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M> + EndpointResult,
+    T: ManagedVecItem + EndpointResult,
 {
     type DecodeAs = ManagedCountedMultiResultVec<M, T>;
 
@@ -111,7 +112,7 @@ where
 impl<M, T> ContractCallArg for &ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M> + ContractCallArg,
+    T: ManagedVecItem + ContractCallArg,
 {
     fn push_dyn_arg<O: DynArgOutput>(&self, output: &mut O) {
         self.len().push_dyn_arg(output);
@@ -124,7 +125,7 @@ where
 impl<M, T> ContractCallArg for ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M> + ContractCallArg,
+    T: ManagedVecItem + ContractCallArg,
 {
     fn push_dyn_arg<O: DynArgOutput>(&self, output: &mut O) {
         (&self).push_dyn_arg(output)
@@ -134,7 +135,7 @@ where
 impl<M, T> TypeAbi for ManagedCountedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
-    T: ManagedVecItem<M> + TypeAbi,
+    T: ManagedVecItem + TypeAbi,
 {
     fn type_name() -> String {
         let mut repr = String::from("counted-variadic<");
