@@ -10,8 +10,6 @@ mod managed_address;
 mod managed_buffer;
 mod managed_buffer_cached_builder;
 mod managed_byte_array;
-mod managed_conversion;
-mod managed_default;
 mod managed_multi_result_vec;
 mod managed_multi_result_vec_counted;
 mod managed_multi_result_vec_eager;
@@ -32,8 +30,6 @@ pub use managed_buffer::ManagedBuffer;
 pub use managed_buffer_cached_builder::ManagedBufferCachedBuilder;
 pub(crate) use managed_byte_array::ManagedBufferSizeContext;
 pub use managed_byte_array::ManagedByteArray;
-pub use managed_conversion::{ManagedFrom, ManagedInto};
-pub use managed_default::ManagedDefault;
 pub use managed_multi_result_vec::{ManagedMultiResultVec, ManagedVarArgs};
 pub use managed_multi_result_vec_counted::{ManagedCountedMultiResultVec, ManagedCountedVarArgs};
 pub use managed_multi_result_vec_eager::{ManagedMultiResultVecEager, ManagedVarArgsEager};
